betty.test_utils.config.collections.mapping module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.config.collections.mapping module

Test utilities for `betty.config.collections.mapping`.

class betty.test_utils.config.collections.mapping.ConfigurationMappingTestBase

  Bases: `Generic`[`_ConfigurationKeyT`, `_ConfigurationT`], `_ConfigurationMappingTestBase`[`_ConfigurationKeyT`, `_ConfigurationT`]

  A base class for testing `betty.config.collections.mapping.ConfigurationMapping` implementations.

class betty.test_utils.config.collections.mapping.OrderedConfigurationMappingTestBase

  Bases: `Generic`[`_ConfigurationKeyT`, `_ConfigurationT`], `_ConfigurationMappingTestBase`[`_ConfigurationKeyT`, `_ConfigurationT`]

  A base class for testing `betty.config.collections.mapping.OrderedConfigurationMapping` implementations.